# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'FeatureStatus',
    'IncomingTrafficPolicy',
    'InitialDownloadPolicy',
    'InitialUploadPolicy',
    'LocalCacheMode',
    'PrivateEndpointServiceConnectionStatus',
]


class FeatureStatus(str, Enum):
    """
    Offline data transfer
    """
    ON = "on"
    OFF = "off"


class IncomingTrafficPolicy(str, Enum):
    """
    Incoming Traffic Policy
    """
    ALLOW_ALL_TRAFFIC = "AllowAllTraffic"
    ALLOW_VIRTUAL_NETWORKS_ONLY = "AllowVirtualNetworksOnly"


class InitialDownloadPolicy(str, Enum):
    """
    Policy for how namespace and files are recalled during FastDr.
    """
    NAMESPACE_ONLY = "NamespaceOnly"
    NAMESPACE_THEN_MODIFIED_FILES = "NamespaceThenModifiedFiles"
    AVOID_TIERED_FILES = "AvoidTieredFiles"


class InitialUploadPolicy(str, Enum):
    """
    Policy for how the initial upload sync session is performed.
    """
    SERVER_AUTHORITATIVE = "ServerAuthoritative"
    MERGE = "Merge"


class LocalCacheMode(str, Enum):
    """
    Policy for enabling follow-the-sun business models: link local cache to cloud behavior to pre-populate before local access.
    """
    DOWNLOAD_NEW_AND_MODIFIED_FILES = "DownloadNewAndModifiedFiles"
    UPDATE_LOCALLY_CACHED_FILES = "UpdateLocallyCachedFiles"


class PrivateEndpointServiceConnectionStatus(str, Enum):
    """
    Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
    """
    PENDING = "Pending"
    APPROVED = "Approved"
    REJECTED = "Rejected"
